::: polaris.benchmark.BenchmarkV2Specification
    options:
        filters: ["!^_", "!md5sum", "!get_cache_path"]


::: polaris.benchmark.BenchmarkSpecification
    options:
        filters: ["!^_", "!md5sum", "!get_cache_path"]

---